/***************************************************************************
*                                                                          *
*  The owner delivers this software "AS IS" AND WITHOUT ANY WARRANTY       *
*  (OTHER THAN TITLE), EXPRESS OR IMPLIED (INCLUDING THOSE OF              *
*  MERCHANTABILITY AND FITNESS FOR PARTICULAR PURPOSE).                    *
*                                                                          *
*  All title and ownership of this Software, which includes, without       *
*  limitation, all rights in patents, copyrights, trademarks and trade     *
*  secrets remains with the owner.  Licensee shall not sell, transfer,     *
*  sublicense, publish, disclose, display or otherwise make available to   *
*  others this Software (or copies thereof), except as outlined in the     *
*  GNU General Public License detailed on the NAIUA Web Site.              *
*                                                                          *
***************************************************************************/

/* Create Table script for DBHygiene */

/sql
set autocommit on;
\p\g

/****** Table used by script to load from AUDITDB *********/
create table tables_list(
	table_name 		varchar(24) 	not null not default,
	table_adds 		integer 	not null not default,
	table_changes 		integer 	not null not default,
	table_deletes 		integer 	not null not default,
	table_trans 		integer 	not null not default,
	num_rows 		integer 	not null not default,
	table_load_factor 	float 		not null not default,
	non_candidate_signal 	i1 		not null not default
)
with duplicates, nojournaling
location = (ii_database);
\p\g

modify tables_list to btree unique on
	table_name
with nonleaffill = 80,
	leaffill = 70,
	fillfactor = 80;
\p\g

grant select on tables_list to public;
\p\g

/****** Table to be used in the future for weekly hygiene *****/
create table tables_list_weekly(
	table_name 		varchar(24) 	not null not default,
	num_rows 		integer 	not null not default,
	table_load_factor 	float 		not null not default
)
with duplicates,
location = (ii_database);
\p\g

modify tables_list_weekly to btree unique on
	table_name
with nonleaffill = 80,
	leaffill = 70,
	fillfactor = 80;
\p\g

/***** Table to hold excluded tables from hygiene *****/
create table tables_exclude(
	table_name 		varchar(24) 	not null not default
)
with duplicates,
location = (ii_database);
\p\g

modify tables_exclude to btree unique on
	table_name
with nonleaffill = 80,
	leaffill = 70,
	fillfactor = 80;
\p\g

/*********************************************************
**  Table to hold thresholds for tables  
**  One row will have the keyword "all" in the tablename
**  column to signify the DEFAULT threshold for all tables
**  Right now only TOT_PERCENT is used.
**********************************************************/
create table table_threshold(
	table_name 	varchar(24) 	not null not default,
	add_percent 	integer 	not null not default,
	chg_percent 	integer 	not null not default,
	del_percent 	integer 	not null not default,
	tot_percent 	integer 	not null not default
)
with duplicates,
location = (ii_database);
\p\g

modify table_threshold to btree unique on
	table_name
with nonleaffill = 80,
	leaffill = 70,
	fillfactor = 80
\p\g

/****** Table that has one row = the number threads *****/
create table table_threads(
	thread_count 	smallint 	not null not default
)
with duplicates,
location = (ii_database);
\p\g

/*******************************************************
** The table which is actually used by the 
** hygiene process 
********************************************************/
create table tables_hygiene(
	table_name 	varchar(24) 	not null not default,
	threshold_no 	smallint 	not null not default
)
with duplicates,
location = (ii_database);
\p\g

modify tables_hygiene to isam unique on
	table_name
with fillfactor = 80;
\p\g

grant select on tables_hygiene to public
\p\g
